YAECS
=====

Yet Another Experiment Config System

|Offial repo| |GitHub last commit (branch)| |License|

--------------

**DISCLAIMER: This repository is the public version of a repository that
is the property of**\ `Reactive
Reality <https://www.reactivereality.com/>`__\ **. This repository IS
NOT OFFICIAL and might not be maintained in the future. Some minor
changes \* are applied from the**\ `official repository
(GitLab) <https://gitlab.com/reactivereality/public/yaecs>`__\ **(under
lesser GNU license).**

This package is a Config System which allows easy manipulation of config
files for safe, clear and repeatable experiments. In a few words, it is:

-  built for Machine Learning with its constraints in mind, but also
   usable out-of-the-box for other kinds of projects;
-  built with scalability in mind and can adapt just as easily to large
   projects investigating hundreds of well-organised parameters across
   many experiments;
-  designed to encourage good coding practices for research purposes,
   and if used rigorously will ensure a number of highly desirable
   properties such that **maintenance-less forward-compatibility** of
   old configs, **easy reproducibility** of any experiment, and
   **extreme clarity** of former experiments for your future self or
   collaborators.

`LINK TO
DOCUMENTATION <https://gitlab.com/reactivereality/public/yaecs/-/wikis/home>`__

.. |Offial repo| image:: https://img.shields.io/badge/official%20repo-YAECS-%23ff9626?logo=gitlab
   :target: https://gitlab.com/reactivereality/public/yaecs
.. |GitHub last commit (branch)| image:: https://img.shields.io/github/last-commit/valentingol/yaecs/main
.. |License| image:: https://img.shields.io/badge/license-LGPLV3%2B-%23c4c2c2
   :target: https://www.gnu.org/licenses/

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   installation
   getting_started
   yaecs_config
   yaecs
   license
